# Firmware Miner

[![image](https://img.shields.io/pypi/v/fwminer.svg)](https://pypi.python.org/pypi/fwminer)

**Miner for security analysis of Firmware**

-   Free software: MIT license
-   Documentation: https://cpuinfo.github.io/fwminer

## Features

-   TODO

## Developer Notes

### Testing

```
pytest
```

### Uploading the distribution archives¶

```
twine upload --repository testpypi dist/*
```

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
